Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Certificate Manager.

Actions, resources, and condition keys for AWS Certificate Manager - Service Authorization Reference

# Actions, resources, and condition keys for AWS Certificate Manager

AWS Certificate Manager (service prefix: `acm` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Certificate Manager
- Resource types defined by AWS Certificate Manager
- Condition keys for AWS Certificate Manager

## Actions defined by AWS Certificate Manager

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddTagsToCertificate | Grants permission to add one or more tags to a certificate | Tagging | certificate* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteCertificate | Grants permission to delete a certificate and its associated private key | Write | certificate* |  |
DescribeCertificate | Grants permission to retreive a certificates and its metadata | Read | certificate* |  |
ExportCertificate | Grants permission to export a private certificate issued by a private certificate authority (CA) for use anywhere | Read | certificate* |  |
GetAccountConfiguration | Grants permission to retrieve account level configuration from AWS Certificate Manager | Read |  |  |
GetCertificate | Grants permission to retrieve a certificate and certificate chain for a certificate ARN | Read | certificate* |  |
ImportCertificate | Grants permission to import a 3rd party certificate into AWS Certificate Manager (ACM) | Write | certificate* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
ListCertificates | Grants permission to retrieve a list of the certificate ARNs and the domain name for each ARN | List |  |  |
ListTagsForCertificate | Grants permission to lists the tags that have been associated with a certificate | Read | certificate* |  |
PutAccountConfiguration | Grants permission to update account level configuration in AWS Certificate Manager | Write |  |  |
RemoveTagsFromCertificate | Grants permission to remove one or more tags from a certificate | Tagging | certificate* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
RenewCertificate | Grants permission to renew an eligible private certificate | Write | certificate* |  |
RequestCertificate | Grants permission to requests a public or private certificate | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
ResendValidationEmail | Grants permission to resend an email to request domain ownership validation | Write | certificate* |  |
UpdateCertificateOptions | Grants permission to update a certificate configuration. Use this to specify whether to opt in to or out of certificate transparency logging | Write | certificate* |  |

## Resource types defined by AWS Certificate Manager

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
certificate | `arn:$ { Partition}:acm:$ { Region}:$ { Account}:certificate/$ { CertificateId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Certificate Manager

AWS Certificate Manager defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filter access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filter access by tag key-value pairs attached to the resource | String
aws:TagKeys | Filter access by the presence of tag keys in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.